/***************************************************************************
 *   Copyright (C) 2004 by Cyril Bosselut                                  *
 *   bosselut@b1project.com                                                *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include "ktag.h"

#include <qlabel.h>

#include <kmainwindow.h>
#include <klocale.h>
#include <kactivelabel.h> 
#include <kcombobox.h>
#include <knuminput.h>
#include <kurlrequester.h>
#include <klineedit.h>
#include <kfiledialog.h>
#include <kmessagebox.h>

class KURLRequester;
class QLabel;
class KActiveLabel;


Ktag::Ktag()
    : ktagDlg()
{
	mGenre->insertStrList(sorted_genres);
	connect(okButton, SIGNAL(clicked()), this, SLOT(writeTags()));
	connect(saveButton, SIGNAL(clicked()), this, SLOT(saveCover()));
}

Ktag::~Ktag()
{
}

void Ktag::readTags(){
	Tags *tags = new Tags(mFile->text());
	if(tags->isMP3()){
		kdDebug("Ktag")<< "mp3 file" << endl;
		tags->ReadId3();
		mNewCover->setFilter("*.png *.jpg *.jpeg *.gif *.bmp *.xbm *.xpm *.pnm");
	}
	else if(tags->isOGG()){
		kdDebug("Ktag")<< "ogg file" << endl;
		tags->ReadVorbis();
		mCover->setDisabled(true);
		coverLabel->setDisabled(true);
		mNewCover->setDisabled(true);
	}
	else{
		kdDebug("Ktag")<< "not supported filetype" << endl;
		KMessageBox::sorry(this, tr2i18n("%1 is not a supported file type (%2)").arg(mFile->text(),tags->mime));
		exit(0);
	}
	KURL *url = new KURL(mFile->text());
	QString path = url->directory(true);
	if(!mAlbum->contains(path.section('/', -1, -1))){
		mAlbum->insertURL(path.section('/', -1, -1));
	}
	if(!mArtist->contains(path.section('/', -2, -2))){
		mArtist->insertURL(path.section('/', -2, -2));
	}
	if(!mAlbum->contains(tags->album)){
		mAlbum->insertURL(tags->album, 0);
	}
	if(!mArtist->contains(tags->artist)){
		mArtist->insertURL(tags->artist, 0);
	}
	if(!mTitle->contains(tags->stitle)){
		mTitle->insertURL(tags->stitle, 0);
	}
	mTrack->setValue(tags->track.toInt());
	mYear->setValue(tags->year.toInt());
	mGenre->setEditURL(tags->genre);
	mComment->setText(tags->comment);
	if(tags->haveCover){
		mCover->setPixmap(QPixmap(tags->cover));
		saveButton->setEnabled(true);
	}
	else{
		saveButton->setDisabled(true);
	}
}

void Ktag::writeTags(){
	Tags *tags = new Tags(mFile->text());
	tags->setInfos(QString::number(mTrack->value()), mArtist->currentText(), mTitle->currentText(), mAlbum->currentText(), mGenre->currentText(), QString::number(mYear->value()), mComment->text(),mNewCover->url());
	mAlbum->setDisabled(true);
	mArtist->setDisabled(true);
	mTitle->setDisabled(true);
	mGenre->setDisabled(true);
	mTrack->setDisabled(true);
	mYear->setDisabled(true);
	mCover->setDisabled(true);
	mComment->setDisabled(true);
	okButton->setDisabled(true);
	quitButton->setDisabled(true);
	if(tags->isMP3()){
		tags->WriteId3();
	}
	else if(tags->isOGG()){
		tags->WriteVorbis();
	}
	mAlbum->setEnabled(true);
	mArtist->setEnabled(true);
	mTitle->setEnabled(true);
	mGenre->setEnabled(true);
	mTrack->setEnabled(true);
	mYear->setEnabled(true);
	mCover->setEnabled(true);
	mComment->setEnabled(true);
	okButton->setEnabled(true);
	quitButton->setEnabled(true);
	readTags();
}

void Ktag::saveCover(){
	QString nfileName;
	nfileName = KFileDialog::getSaveFileName(KURL(mFile->text()).directory(false) + "cover.png", "*.png", 0, "Save Cover");
	if(nfileName != ""){
		(mCover->pixmap())->save(nfileName, "PNG", 0);
	}
}

#include "ktag.moc"
